@@ -463,7 +463,7 @@ static void dialog_add_edit(GtkTreeIter iter, gboolean edit, PersonalMenuSetup *
 	GtkWidget *hbox;
 	GtkWidget *caption;
 	GtkWidget *addByDesktopFile;
-	GtkWidget *appNameEntry, *executableEntry, *iconButton;
+	GtkWidget *appNameEntry, *executableEntry, *iconButton, *iconFileButton;
 	GtkWidget *termCheckBox, *rootCheckBox;
 	GtkWidget *scroll;
 	int res;
@@ -502,13 +502,15 @@ static void dialog_add_edit(GtkTreeIter iter, gboolean edit, PersonalMenuSetup *
 
 	setup->context="hildon";
 	hbox=gtk_hbox_new(FALSE,0);
-	iconButton=gtk_button_new_with_label("Select Icon");
+	iconButton=gtk_button_new_with_label("Select icon");
 	setup->iconPreview=gtk_image_new_from_icon_name("qgn_list_gene_default_app",GTK_ICON_SIZE_SMALL_TOOLBAR);
 	gtk_box_pack_start(GTK_BOX(hbox),setup->iconPreview,FALSE,FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox),iconButton,FALSE,FALSE,0);
+	g_signal_connect(G_OBJECT(iconButton),"clicked",G_CALLBACK(select_icon),setup);
+	
 	caption=hildon_caption_new(NULL,"Icon to display",hbox,NULL,HILDON_CAPTION_MANDATORY);
 	gtk_box_pack_start(GTK_BOX(vbox),caption,FALSE,FALSE,0);
-	g_signal_connect(G_OBJECT(iconButton),"clicked",G_CALLBACK(select_icon),setup);
+	
 
 	termCheckBox=gtk_check_button_new_with_label("Run in terminal?");
 	gtk_box_pack_start(GTK_BOX(vbox),termCheckBox,FALSE,FALSE,0);
